@@ -2,6 +2,7 @@
 # -*- coding: utf-8 -*-
 
 import hot, es, dataDispose, itemCF, test, time
+#import es, test
 
 def startUpdateHot(isTest):
 	es.setEnv(isTest)
@@ -19,14 +20,18 @@ def updateHistoryActions(isTest):
 	es.setEnv(isTest)
 	dataDispose.updateHistoryActions()
 
+def logToHive(isTest):
+	es.setEnv(isTest)
+	test.logToHive()
+
 def testFunc(isTest):
 	#disposeData(isTest)
 	es.setEnv(isTest)
-	hot.startUpdate(isTest, 'config.ini')
+	#hot.startUpdate(isTest, 'config.ini')
 	#print(es.searchDbConfig())
 	#print('delete post works record: ' + ('success ' if dataDispose.deletePastWorksRecord() else 'fail '))
 	#dataDispose.deletePastWorksRecord()
-	#test.test()
+	test.test()
 	'''
 	while True:
 		es.setEnv(isTest)
