@@ -25,20 +25,21 @@ class Works(object):
 		self.resShowPlay = 0
 		self.timeCount = 0
 		self.timeTotal = 0
-
-		self.score = 0
+		self.unsubPlay = 0
 
 		self.playUids = set()
 		self.shareUids = set()
 		#self.longPlayUids = set()
 		self.resShowUids = set()
 		self.resShowPlayUids = set()
+		self.unsubPlayUids = set()
 
 		self.historyPlay = 0
 		self.historyShare = 0
 		#self.historyLongPlay = 0
 		self.historyResShow = 0
 		self.historyResShowPlay = 0
+		self.historyUnsubPlay = 0
 
 	def updateHistory(self, history):
 		self.historyPlay = history['play']
@@ -55,6 +56,8 @@ class Works(object):
 		self.resShowPlay = len(self.resShowPlayUids) + self.historyResShowPlay
 		self.timeCount += history['timeCount']
 		self.timeTotal += history['timeTotal']
+		self.historyUnsubPlay = history['unsubPlay']
+		self.unsubPlay = len(self.unsubPlayUids) + self.historyUnsubPlay
 
 	'''
 	def updateAction(self, action):
@@ -108,14 +111,17 @@ class Works(object):
 		elif actionId == 2:
 			self.resShowPlayUids.add(uid)
 			self.resShowPlay = len(self.resShowPlayUids) + self.historyResShowPlay
+		elif actionId == 3:
+			self.unsubPlayUids.add(uid)
+			self.unsubPlay = len(self.unsubPlayUids) + self.historyUnsubPlay
 
 	def toSaveEsData(self):
-		return {"vid": self.vid, "score": self.score, "time": self.endTime, "aid": self.aid, "title": self.title, "play": self.play, "share": self.share, "sub": self.sub, "like": self.like, "resShow": self.resShow, "resShowPlay": self.resShowPlay, "videourl": self.videourl, "timeCount": self.timeCount, "timeTotal": self.timeTotal, "duration": self.duration}
+		return {"vid": self.vid, "time": self.endTime, "aid": self.aid, "title": self.title, "play": self.play, "share": self.share, "sub": self.sub, "like": self.like, "resShow": self.resShow, "resShowPlay": self.resShowPlay, "videourl": self.videourl, "timeCount": self.timeCount, "timeTotal": self.timeTotal, "duration": self.duration, "unsubPlay": self.unsubPlay}
 
 	def updateActions(self, endTime, startTime=0, needCreateLimit=False):
 		self.startTime = min(self.startTime, startTime) if self.startTime != -1 else startTime
 		self.endTime = max(self.endTime, endTime)
-		play, share, like, sub, resShow, resShowPlay, timeCount, timeTotal = self.getHotDataByVid(self.vid, startTime, endTime, needCreateLimit)
+		play, share, like, sub, resShow, resShowPlay, timeCount, timeTotal, unsubPlay = self.getHotDataByVid(self.vid, startTime, endTime, needCreateLimit)
 		self.play = play
 		self.share = share
 		self.like = like
@@ -124,6 +130,7 @@ class Works(object):
 		self.resShowPlay = resShowPlay
 		self.timeCount = timeCount
 		self.timeTotal = timeTotal
+		self.unsubPlay = unsubPlay
 		gc.collect()
 
 	def getHotDataByVid(self, vid, startTime, endTime, needCreateLimit):
@@ -149,7 +156,7 @@ class Works(object):
 		body['aggs']['time_total'] = {"sum": {"field": "value"}}
 		timeTotal = es.searchStatisticsAggs('hot_actions', body)['time_total']['value']
 
-		return counts[8], counts[9], counts[4] - counts[5], counts[6] - counts[7], counts[1], counts[2], timeCount, timeTotal
+		return counts[8], counts[9], counts[4] - counts[5], counts[6] - counts[7], counts[1], counts[2], timeCount, timeTotal, counts[3]
 
 	def getDataByVid(self, vid, startTime, endTime, needCreateLimit):
 		#now = time.time()
