@@ -9,8 +9,9 @@ esTimeFormatNoMs = u"%Y-%m-%dT%H:%M:%SZ"
 testEsclient = Elasticsearch(['119.23.69.206:9200'], timeout=60)
 devEsclient = Elasticsearch(['192.168.0.100:9200'], timeout=60)
 localEsclient = Elasticsearch(['127.0.0.1:9200'], http_auth=('elastic', 'changeme'), timeout=60)
-#dataEsclient = Elasticsearch(['10.168.0.119:9200', '10.168.0.121:9200', '10.168.0.118:9200', '10.168.0.127:9200'], http_auth=('huangzhen', 'df25j0934j4y09hjoijoigef'), timeout=120)
-dataEsclient = Elasticsearch(['10.168.0.133:9200', '10.168.0.141:9200', '10.168.0.140:9200', '10.168.0.143:9200', '10.168.0.146:9200'], http_auth=('huangzhen', 'df25j0934j4y09hjoijoigef'), timeout=120)
+#dataEsclient = Elasticsearch(['10.168.0.119:9200', '10.168.0.121:9200', '10.168.0.127:9200'], http_auth=('huangzhen', 'df25j0934j4y09hjoijoigef'), timeout=120)
+#dataEsclient = Elasticsearch(['10.168.0.133:9200', '10.168.0.141:9200', '10.168.0.140:9200', '10.168.0.143:9200', '10.168.0.146:9200'], http_auth=('huangzhen', 'df25j0934j4y09hjoijoigef'), timeout=120)
+dataEsclient = Elasticsearch(['10.168.0.143:9200', '10.167.0.246:7200', '10.0.0.53:9200'], http_auth=('huangzhen', 'df25j0934j4y09hjoijoigef'), timeout=120)
 relEsclient = Elasticsearch(['10.32.0.223:9200', '10.33.0.11:9200', '10.167.0.246:9200'], http_auth=('huangzhen', 'huangzhen'), timeout=60)
 
 
@@ -28,6 +29,7 @@ def getIntByVid(vid):
 	return vidDict[vid] if vidDict.has_key(vid) else 0
 
 def initVidDict():
+	global vidDict
 	db = MySQLdb.connect("rm-bp1j29cm99gj425n2.mysql.rds.aliyuncs.com", "mitaoroot", "lks213#%%Jfiewrj", "db_nt_recommendcache", charset='utf8')
 	for item in searchDb(db, 'select * from tb_videointid limit 30000'):
 		vidDict[item[0]] = item[1]
@@ -76,7 +78,7 @@ def updateRedisWorksHots(worksHots):
 def getAllUids(lastUid):
 	db = MySQLdb.connect("rm-bp10y51s402rn0kut.mysql.rds.aliyuncs.com", "mitaoroot", "lks213#%%Jfiewrj", "db_nt_user", charset='utf8')
 	uids = []
-	for item in searchDb(db, 'select uid from tb_user where uid > ' + str(lastUid) + ' order by uid asc limit 50000'):
+	for item in searchDb(db, 'select uid from tb_user where uid > ' + str(lastUid) + ' order by uid asc limit 100'):
 		uids.append(item[0])
 	db.close()
 	return uids
@@ -248,6 +250,8 @@ def scrollSearch(fullIndex, doc_type, body, searchAll=True, log=True, version=Fa
 			scroll_id = result['_scroll_id']
 			#print(scroll_id)
 			result = esclient.scroll(scroll_id=scroll_id, scroll='1m')
+		if len(hits) != 0:
+			esclient.clear_scroll(scroll_id=scroll_id)
 	else:
 		hits.extend(esclient.search(index=fullIndex, doc_type=doc_type, body=body, version=version)['hits']['hits'])
 	if log:
