@@ -12,7 +12,7 @@ def cycleUpdateHotList(configFileName, isTest):
 	worksHistory, historyTime, endTime = getNewestHistory()
 	oriWorksDict = {}
 	while True:
-		#try:
+		try:
 			start = time.time()
 			ilog.info('start:' + str(start) + '(' + time.strftime(es.esTimeFormatNoMs, time.localtime(start)) + ')')
 			
@@ -34,9 +34,9 @@ def cycleUpdateHotList(configFileName, isTest):
 			maxInterval = 150 if isTest else 600
 			if cost < maxInterval:
 				time.sleep(maxInterval - cost)
-		#except Exception as error:
-		#	ilog.info('Error: (' + time.strftime(es.esTimeFormatNoMs, time.localtime(time.time())) + ')' + str(error))
-		#	time.sleep(600)
+		except Exception as error:
+			ilog.info('Error: (' + time.strftime(es.esTimeFormatNoMs, time.localtime(time.time())) + ')' + str(error))
+			time.sleep(600)
 
 def getNewestHistory():
 	worksHistory = dataDispose.getWorksHistory()
