@@ -73,14 +73,15 @@ def calWorksScore(worksList):
 	worksArgs = []
 	for works in worksList:
 		works.play = works.resShowPlay
-		resShowTrust = min(works.resShow, Trust['resShow']) / Trust['resShow']
-		playTrust = min(works.play, Trust['play']) / Trust['play']
-		timeCountTrust = min(works.timeCount, Trust['timeCount']) / Trust['timeCount']
+		resShowTrust = min(works.resShow, Trust['resShow']) * 1.0  / Trust['resShow']
+		playTrust = min(works.play, Trust['play']) * 1.0  / Trust['play']
+		timeCountTrust = min(works.timeCount, Trust['timeCount']) * 1.0  / Trust['timeCount']
+		unsubPlayTrust = min(works.unsubPlay, Trust['play']) * 1.0  / Trust['play']
 		conv = 0 if works.resShow <= 0 else works.resShowPlay * 1.0 / works.resShow * resShowTrust
 		likeRatio = 0 if works.play <= 0 else works.like * 1.0 / works.play * playTrust
 		shareRatio = 0 if works.play <= 0 else works.share * 1.0 / works.play * playTrust
 		longPlayRatio = 0 if works.timeCount <= 0 or works.duration <= 0 else works.timeTotal * 1.0 / works.timeCount / works.duration * getPlayCompleteWeight(works.duration) * timeCountTrust
-		subRatio = 0 if works.play <= 0 else works.sub * 1.0 / works.play * playTrust
+		subRatio = 0 if works.unsubPlay <= 0 else works.sub * 1.0 / works.unsubPlay * unsubPlayTrust
 		worksArgs.append([conv, likeRatio, shareRatio, longPlayRatio, subRatio])
 	worksArgsMat = mat(worksArgs)
 	worksArgsMat[worksArgsMat < 0] = 0
@@ -100,11 +101,20 @@ def calHotV2(worksList):
 	hotList = {}
 	for index, works in enumerate(worksList):
 		vid = works.vid
-		hotData = works.toSaveEsData()
+		hotData = {}
+		hotData['vid'] = works.vid
+		hotData['aid'] = works.aid
+		hotData['title'] = works.title
 		hotData['hot'] = works.score
 		hotData['exposure'] = works.resShow
 		hotData['converRatio'] = 0 if works.resShow <= 0 else works.resShowPlay * 1.0 / works.resShow
 		hotData['completeRatio'] = 0 if works.timeCount <= 0 or works.duration <= 0 else works.timeTotal * 1.0 / works.timeCount / works.duration
+		hotData['click'] = works.resShowPlay
+		hotData['like'] = works.like
+		hotData['share'] = works.share
+		hotData['play'] = works.play
+		hotData['subscribeRatio'] = 0 if works.unsubPlay <= 0 else works.sub * 1.0 / works.unsubPlay
+		hotData['isNew'] = works.publishTime < 72 and works.resShow <= 1000
 		hotList[vid] = hotData
 
 	hotListFinal = {}
